@@ -4,8 +4,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 373827;
-var summary = 'Do not assert: OBJ_GET_CLASS(cx, obj)->flags & JSCLASS_HAS_PRIVATE';
+var BUGNUMBER = 452498;
+var summary = 'TM: upvar2 regression tests';
 var actual = '';
 var expect = '';
 
@@ -19,8 +19,15 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  let ([] = [{x: function(){}}]) { };
+
+// ------- Comment #63 From Brendan Eich
+
+  function f(that) {
+    for (ix in this)
+      print(ix);
+    for (let ix in that)
+      ;
+  }
 
   reportCompare(expect, actual, summary);
 
