@@ -14,22 +14,35 @@ function test() {
   ensureSocialEnabled();
 
   SocialService.addProvider(manifest, function (provider) {
+    // enable the provider
+    provider.enabled = true;
+
     ok(provider.enabled, "provider is initially enabled");
-    ok(provider.port, "should be able to get a port from enabled provider");
+    let port = provider.getWorkerPort();
+    ok(port, "should be able to get a port from enabled provider");
+    port.close();
     ok(provider.workerAPI, "should be able to get a workerAPI from enabled provider");
 
     provider.enabled = false;
 
     ok(!provider.enabled, "provider is now disabled");
-    ok(!provider.port, "shouldn't be able to get a port from disabled provider");
+    port = provider.getWorkerPort();
+    ok(!port, "shouldn't be able to get a port from disabled provider");
     ok(!provider.workerAPI, "shouldn't be able to get a workerAPI from disabled provider");
 
     provider.enabled = true;
 
     ok(provider.enabled, "provider is re-enabled");
-    ok(provider.port, "should be able to get a port from re-enabled provider");
+    let port = provider.getWorkerPort();
+    ok(port, "should be able to get a port from re-enabled provider");
+    port.close();
     ok(provider.workerAPI, "should be able to get a workerAPI from re-enabled provider");
 
-    SocialService.removeProvider(provider.origin, finish);
+    SocialService.removeProvider(provider.origin, function() {
+      ok(!provider.enabled, "removing an enabled provider should have disabled the provider");
+      let port = provider.getWorkerPort();
+      ok(!port, "should not be able to get a port after removing the provider");
+      finish();
+    });
   });
 }
